@@ -78,11 +78,20 @@ class FieldSchema:
         # self.type = DataType(int(raw.type))
 
         for type_param in raw.type_params:
-            self.params[type_param.key] = type_param.value
+            if type_param.key == "params":
+                import json
+                self.params[type_param.key] = json.loads(type_param.value)
+            else:
+                self.params[type_param.key] = type_param.value
 
         index_dict = dict()
         for index_param in raw.index_params:
-            index_dict[index_param.key] = index_param.value
+            if index_param.key == "params":
+                import json
+                index_dict[index_param.key] = json.loads(index_param.value)
+            else:
+                index_dict[index_param.key] = index_param.value
+
         self.indexes.extend([index_dict])
 
     def dict(self):
