@@ -1,4 +1,5 @@
 import datetime
+import time
 from urllib.parse import urlparse
 import logging
 import threading
@@ -500,7 +501,9 @@ class GrpcHandler(AbsMilvus):
 
         if status.error_code != 0:
             raise BaseException(status.error_code, status.reason)
-
+        sync = kwargs.get("sync", True)
+        if sync:
+            self.wait_index_building_success(collection_name=collection_name, field_name= field_name)
         return Status(status.error_code, status.reason)
 
     @error_handler(None)
@@ -530,8 +533,10 @@ class GrpcHandler(AbsMilvus):
         raise BaseException(status.error_code, status.reason)
 
     @error_handler()
-    def wait_index_building_success(self, collection_name, field_name):
+    def wait_index_building_success(self, collection_name, field_name, timeout=30, **kwargs):
         while True:
+            time.sleep(0.5)
+            print("\n***********  waiting for building index ***********\n")
             if self.get_index_progress(collection_name=collection_name, field_name=field_name):
                 break
 
