@@ -382,7 +382,7 @@ class Prepare:
 
         query = service_msg_types.Query(
             collection_name=collection_name,
-            partition_tags=partition_tags or "",
+            partition_tags=partition_tags,
         )
 
         duplicated_entities = copy.deepcopy(query_entities)
@@ -443,12 +443,17 @@ class Prepare:
         # index_params.collection_name = collection_name
         # index_params.field_name = field_name
 
+        def dump(tv):
+            if isinstance(tv, dict):
+                import json
+                return json.dumps(tv)
+            return str(tv)
         if isinstance(params, dict):
             for tk, tv in params.items():
                 if tk == "dim":
                     if not tv or not isinstance(tv, int):
                         raise ParamError("dim must be of int!")
-                kv_pair = common_types.KeyValuePair(key=str(tk), value=str(tv))
+                kv_pair = common_types.KeyValuePair(key=str(tk), value=dump(tv))
                 index_params.extra_params.append(kv_pair)
 
         return index_params
@@ -456,9 +461,9 @@ class Prepare:
     @classmethod
     def describe_index_request(cls, collection_name, field_name):
 
-        return service_msg_types.DescribeIndexRequest(collection_name, field_name)
+        return service_msg_types.DescribeIndexRequest(collection_name=collection_name, field_name=field_name)
 
     @classmethod
     def describe_index_progress_request(cls, collection_name, field_name):
 
-        return service_msg_types.DescribeIndexProgressRequest(collection_name, field_name)
+        return service_msg_types.DescribeIndexProgressRequest(collection_name=collection_name, field_name=field_name)
