@@ -436,11 +436,25 @@ class Milvus:
     @check_connect
     def get_index_info(self, collection_name, field_name, timeout=30):
 
+        check_pass_param(collection_name=collection_name)
         with self._connection() as handler:
             return handler.get_index_info(collection_name, field_name, timeout)
 
     @check_connect
-    def get_index_process(self, collection_name, field_name, timeout=30):
+    def get_index_progress(self, collection_name, field_name, timeout=30):
 
+        check_pass_param(collection_name=collection_name)
         with self._connection() as handler:
             return handler.get_index_progress(collection_name, field_name, timeout)
+
+    @check_connect
+    def wait_index_building_success(self, collection_name, field_name, timeout=30):
+
+        check_pass_param(collection_name=collection_name)
+        with self._connection() as handler:
+            return handler.wait_index_building_success(collection_name, field_name, timeout)
+
+    @check_connect
+    def _cmd(self, *args, **kwargs):
+        if "mode" in args or "mode" in kwargs:
+            return "CPU"
