@@ -55,7 +55,7 @@ default_index_params = [
     {"nlist": 128},
     {"nlist": 128},
     {"nlist": 128},
-    {"nlist": 128, "m": 16},
+    {"nlist": 128, "m": 16, "nbits": 8},
     {"M": 48, "efConstruction": 500},
     # {"search_length": 50, "out_degree": 40, "candidate_pool_size": 100, "knng": 50},
     {"n_trees": 50},
